This function creates a standalone Shiny application that demonstrates the swimmerplot module with example data from the pharmaversesdtm package.
This function creates a standalone Shiny application that demonstrates the swimmerplot module with example data from the pharmaversesdtm package.