Run an example swimmer plot module in the module manager
Source:R/mock_swimmerplot_mm.R
mock_swimmerplot_mm.RdLaunches an example app that shows a swimmer plot module integrated in the module manager surface. Displays data prepared from the pharmaversesdtm package.