Skip to contents

This function creates a standalone Shiny application that demonstrates the swimmerplot module with example data from the pharmaversesdtm package.

Usage

mock_swimmerplot()

Examples

if (FALSE) { # \dontrun{
mock_swimmerplot()
} # }