mock_swimmerplot.Rd
This function creates a standalone Shiny application that demonstrates the swimmerplot module with example data from the pharmaversesdtm package.
mock_swimmerplot()
if (FALSE) { # \dontrun{ mock_swimmerplot() } # }